##
##  cego.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   FIXME: rse: seems to have problems during building if old version is still installed

#   package version
%define       V_cego     2.49.3
%define       V_lfcbase  1.18.6
%define       V_lfcxml   1.3.7
%define       V_jdbc     1.11.0

#   package information
Name:         cego
Summary:      Relational Database Management System (RDBMS)
URL:          http://www.lemke-it.com/opensource.html
Vendor:       Bjrn Lemke
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Database
License:      GPL
Version:      %{V_cego}
Release:      20240628

#   package options
%option       with_jdbc   no

#   list of sources
Source0:      http://www.lemke-it.com/lfcbase-%{V_lfcbase}.tar.gz
Source1:      http://www.lemke-it.com/lfcxml-%{V_lfcxml}.tar.gz
Source2:      http://www.lemke-it.com/cego-%{V_cego}.tar.gz
Source3:      http://www.lemke-it.com/cegojdbc-%{V_jdbc}.jar
Patch0:       cego.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes, make
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  readline, ncurses
PreReq:       readline, ncurses
%if "%{with_jdbc}" == "yes"
PreReq:       java, JAVA-JDK
%endif

%description
    Cego is a Relational Database Management System (RDBMS). Cego
    supports transactional SQL query requests in a multithreaded
    architecture. For high availablility requirements, Cego supports a
    database shadowing feature. Several compute nodes can be defined in
    a Cego database configuration, where each node is able to manage a
    number of so called table sets. For each tableset, a backup node
    can be defined, which runs is recover mode for the corresponding
    tableset. If required, the tableset can be switched to the backup
    node and this node gets the active node for the tableset.

%track
    prog cego:lfcbase = {
        version   = %{V_lfcbase}
        url       = http://www.lemke-it.com/litexec?request=pubcego&user=&lang=en
        regex     = lfcbase-(__VER__)\.tar\.gz
    }
    prog cego:lfcxml = {
        version   = %{V_lfcxml}
        url       = http://www.lemke-it.com/litexec?request=pubcego&user=&lang=en
        regex     = lfcxml-(__VER__)\.tar\.gz
    }
    prog cego:cego = {
        version   = %{V_cego}
        url       = http://www.lemke-it.com/litexec?request=pubcego&user=&lang=en
        regex     = cego-(__VER__)\.tar\.gz
    }
    prog cego:jdbc = {
        version   = %{V_jdbc}
        url       = http://www.lemke-it.com/litexec?request=pubcego&user=&lang=en
        regex     = cegojdbc-(__VER__)\.jar
    }

%prep
    %setup -q -c
    %setup -q -T -D -a 1
    %setup -q -T -D -a 2
    %patch -p0 -d cego-%{V_cego}

%build
    ( cd lfcbase-%{V_lfcbase}
      export CC="%{l_cc}"
      export CXX="%{l_cxx}"
      export CFLAGS="%{l_cflags -O}"
      export CXXFLAGS="%{l_cxxflags -O}"
      export CPPFLAGS="%{l_cppflags}"
      export LDFLAGS="%{l_ldflags}"
      ./configure \
          --prefix=%{l_prefix} \
          --disable-shared
      %{l_make} %{l_mflags -O}
      ln -s src lfcbase
    ) || exit $?
    ( cd lfcxml-%{V_lfcxml}
      export CC="%{l_cc}"
      export CXX="%{l_cxx}"
      export CFLAGS="%{l_cflags -O}"
      export CXXFLAGS="%{l_cxxflags -O}"
      export CPPFLAGS="%{l_cppflags} -I`pwd`/../lfcbase-%{V_lfcbase} -I`pwd`/../lfcbase-%{V_lfcbase}/src"
      export LDFLAGS="%{l_ldflags} -L`pwd`/../lfcbase-%{V_lfcbase}/src"
      ./configure \
          --prefix=%{l_prefix} \
          --disable-shared
      %{l_make} %{l_mflags -O}
      ln -s src lfcxml
    ) || exit $?
    ( cd cego-%{V_cego}
      export CC="%{l_cc}"
      export CXX="%{l_cxx}"
      export CFLAGS="%{l_cflags -O}"
      export CXXFLAGS="%{l_cxxflags -O}"
      export CPPFLAGS="%{l_cppflags} -I`pwd`/../lfcbase-%{V_lfcbase} -I`pwd`/../lfcbase-%{V_lfcbase}/src -I`pwd`/../lfcxml-%{V_lfcxml} -I`pwd`/../lfcxml-%{V_lfcxml}/src"
      export LDFLAGS="%{l_ldflags} -L`pwd`/../lfcbase-%{V_lfcbase}/src -L`pwd`/../lfcbase-%{V_lfcbase}/src/.libs -L`pwd`/../lfcxml-%{V_lfcxml}/src -L`pwd`/../lfcxml-%{V_lfcxml}/src/.libs"
      export LIBS="-llfcxml -llfcbase"
      case "%{l_platform -t}" in
          *-linux*   ) LIBS="$LIBS -lcrypt" ;;
          *-freebsd* ) LIBS="$LIBS -lcrypt" ;;
          *-netbsd*  ) LIBS="$LIBS -lcrypt" ;;
      esac
      ./configure \
          --prefix=%{l_prefix} \
          --disable-shared
      %{l_make} %{l_mflags -O}
    ) || exit $?

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/lib \
        $RPM_BUILD_ROOT%{l_prefix}/include/cego
    ( cd lfcbase-%{V_lfcbase}
      #   %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    ) || exit $?
    ( cd lfcxml-%{V_lfcxml}
      #   %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    ) || exit $?
    ( cd cego-%{V_cego}
      %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    ) || exit $?
%if "%{with_jdbc}" == "yes"
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/lib/cego
    %{l_shtool} install -c -m 644 \
        %{SOURCE cegojdbc-%{V_jdbc}.jar} \
        $RPM_BUILD_ROOT%{l_prefix}/lib/cego/cego.jar
%endif
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

